package com.webonlineapp.hyjavachartsdemo;

import java.io.IOException;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.List;
import java.util.Optional;
import java.util.Random;
import java.util.stream.Stream;

import com.hyjavacharts.LibraryInfo;
import com.hyjavacharts.chart.Highchart;
import com.vaadin.icons.VaadinIcons;
import com.vaadin.server.StreamResource;
import com.vaadin.server.StreamResource.StreamSource;
import com.vaadin.shared.ui.ContentMode;
import com.vaadin.ui.Alignment;
import com.vaadin.ui.Button;
import com.vaadin.ui.Component;
import com.vaadin.ui.Grid;
import com.vaadin.ui.HorizontalLayout;
import com.vaadin.ui.Image;
import com.vaadin.ui.Label;
import com.vaadin.ui.Panel;
import com.vaadin.ui.TabSheet;
import com.vaadin.ui.TabSheet.Tab;
import com.vaadin.ui.TextArea;
import com.vaadin.ui.VerticalLayout;
import com.vaadin.ui.themes.ValoTheme;
import com.webonlineapp.highchartsvaadincomponent.HighChartComponent;
import com.webonlineapp.highchartsvaadincomponent.HighChartFactory;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChart;
import com.webonlineapp.hyjavachartsdemo.charts.DemoCharts;
import com.webonlineapp.hyjavachartsdemo.exportserver.ChartImageSource;
import com.webonlineapp.hyjavachartsdemo.util.GeneralUtil;
import com.webonlineapp.hyjavachartsdemo.util.JavascriptUtil;

public class DemoPage {
	private Grid<DemoChart> demoCharts;
	private List<DemoChart> demoChartsList;
	private Label sourceCode = new Label("");
	private Label jsCode = new Label("");
	
	HighChartComponent chartComponent = new HighChartComponent();
	
	private String prevChart = "";

	
	/**
	 * 
	 * @param exportServer
	 * @return
	 */
	public Component buildPage(boolean exportServer) {
		if (exportServer) {
			demoChartsList = new DemoCharts().getDemoChartsExportServerList();
		}
		else {
			demoChartsList = new DemoCharts().getDemoChartsList();
		}
		
		final VerticalLayout layout = new VerticalLayout();
		layout.setMargin(false);
		layout.setSpacing(false);

        layout.addComponent(buildHeader(exportServer));
        layout.addComponent(buildTabSheet(exportServer));
        
        return layout;
	}
	
	/**
	 * 
	 * @param exportServer
	 * @return
	 */
	private Component buildHeader(boolean exportServer) {
		HorizontalLayout header = new HorizontalLayout();
        header.setMargin(false);
        Label h1 = new Label(exportServer ? "Highcharts Node.js Server Demonstration" : "Highcharts Demonstration");
        h1.addStyleName("h1");
        header.addComponent(h1);
        Label versions = new Label("using HyJavaCharts library v" + LibraryInfo.getHyJavaChartsAPIVersion() 
        		+ (exportServer ? "" : " and Highcharts v" + LibraryInfo.getHighchartsAPIVersion()));
        versions.addStyleName(ValoTheme.LABEL_SMALL);
        header.addComponent(versions);
        header.setComponentAlignment(versions, Alignment.MIDDLE_LEFT);

    	return header;
    }
	
	/**
	 * 
	 * @param exportServer
	 * @return
	 */
	private Component buildTabSheet(boolean exportServer) {
		TabSheet tabSheet = new TabSheet();
    	tabSheet.addStyleName("padded-tabbar");
    	
    	tabSheet.addSelectedTabChangeListener(new TabSheet.SelectedTabChangeListener() {
 			private static final long serialVersionUID = 1L;

			@Override
            public void selectedTabChange(TabSheet.SelectedTabChangeEvent event) {
				if (tabSheet.getTabPosition(tabSheet.getTab(tabSheet.getSelectedTab())) == 1) {
	                com.vaadin.ui.JavaScript.eval("setTimeout(function(){prettyPrint();},300);");
				}
            }
        });

    	Tab listTab = tabSheet.addTab(buildDemoTab(exportServer), "Example Chart");
    	listTab.setIcon(VaadinIcons.BAR_CHART);
    	
        Tab sourceTab = tabSheet.addTab(buildSourceTab(), "Java Source Code");
        sourceTab.setIcon(VaadinIcons.COFFEE);
        
        Tab jsTab = tabSheet.addTab(buildJsTab(), "Generated Javascript");
        jsTab.setIcon(VaadinIcons.CURLY_BRACKETS);
        
        if (Properties.SHOW_TEST_TAB) {
	        Tab detailTab = tabSheet.addTab(buildTestTab(), "Test");
	        detailTab.setIcon(VaadinIcons.CHECK);
        }
        
        demoCharts.select(demoChartsList.get(0));

    	return tabSheet;
    }
	
	/**
	 * 
	 * @param exportServer
	 * @return
	 */
	private Component buildDemoTab(boolean exportServer) {
    	VerticalLayout demoTabContent = new VerticalLayout();
    	demoTabContent.setMargin(false);
        
        HorizontalLayout hor = new HorizontalLayout();
        hor.setMargin(false);
        hor.setSpacing(false);
        hor.setWidth("100%");
        VerticalLayout menuArea = new VerticalLayout();
        VerticalLayout chartArea = new VerticalLayout();
        hor.addComponent(menuArea);
        hor.addComponent(chartArea);
        hor.setComponentAlignment(chartArea, Alignment.TOP_LEFT);
        hor.setExpandRatio(menuArea, 4);
        hor.setExpandRatio(chartArea, 10);
        
        demoCharts = new Grid<DemoChart>();
        demoCharts.setWidth("100%");
        demoCharts.setHeightByRows(15);
        demoCharts.addColumn(DemoChart::getName).setCaption("Example Charts");
        demoCharts.setItems(demoChartsList);
        
        demoCharts.addSelectionListener(event -> {
    		Optional<DemoChart> first = event.getFirstSelectedItem();
    		
    		if (first.isPresent()) {
         		DemoChart selectedDemoChart = first.get();
        		
         		if (selectedDemoChart.getChart() != null) {
         			Highchart hc = selectedDemoChart.getChart().configure();
         			
         			String globalOptionsJs = hc.globalOptionsToJs();
         			String chartOptionsJs = hc.chartOptionsToJs();
         			
         			if (exportServer) {
         				buildExportServerDemo(chartArea, globalOptionsJs, chartOptionsJs);
         			}
         			else {
	         			if (prevChart.equals("Parallel Coordinates")) {
	         				JavascriptUtil.removeStyleSheetRule(0);
	         			}
	         			
	         			if (selectedDemoChart.getName().equals("Parallel Coordinates")) {
	         				JavascriptUtil.addStyleSheetRule(JavascriptUtil.HIGHCHARTS_SERIES_HOVER, 0);
	         			}
	         			prevChart = selectedDemoChart.getName();
	        			
		        		if (globalOptionsJs != null) 
		        			chartComponent.setOptions(globalOptionsJs);
		        		chartComponent.setChartoptions(chartOptionsJs);
		        		chartComponent.setWidth(selectedDemoChart.getChart().getWidth());
		        		chartComponent.setHeight(selectedDemoChart.getChart().getHeight());
		        		chartArea.removeAllComponents();
		        		chartArea.addComponent(chartComponent);
		        		
		        		if (Properties.SHOW_CHANGE_TITLE) {
			        		Button updateChart = new Button("Change Title");
			        		updateChart.addClickListener(clickEvent -> {
			        			chartComponent.manipulateChart("chart.setTitle({ text: 'A new title'});");
			        		});
			        		chartArea.addComponent(updateChart);
		        		}
         			}
	        		
	        		// Show source code
	        		addSourceCode(selectedDemoChart.getChart().getClass().getName());
	        		
	        		// Show js
	        		addJs(globalOptionsJs, chartOptionsJs);
         		}
    		}
    	});

        menuArea.addComponent(demoCharts);        
        demoTabContent.addComponent(hor);
        
    	return demoTabContent;
    }
	
	/**
	 * 
	 * @param chartArea
	 * @param globalOptionsJs
	 * @param chartOptionsJs
	 */
	private void buildExportServerDemo(VerticalLayout chartArea, String globalOptionsJs, String chartOptionsJs) {
		chartArea.removeAllComponents();
		
		Label desc = new Label();
		desc.setWidth("100%");
		desc.setValue("Generate charts using the HyJavaCharts Library and the Highcharts Node.js Server. " + 
				"<br>The chart options Javascript is generated on the server using HyJavaCharts and sent to the Node.js server. " + 
				"<br>The Node.js server returns an image file. No Javascript is executed on the client browser.");
		desc.setContentMode(ContentMode.HTML);
		chartArea.addComponent(desc);
		
		Button export = new Button("Send to Node.js Server");
		chartArea.addComponent(export);

		export.addClickListener(clickEvent -> {
			Random rand = new Random();
			
			chartArea.removeAllComponents();
    		StreamSource imagesource = new ChartImageSource(globalOptionsJs, chartOptionsJs);
    		StreamResource resource = new StreamResource(imagesource, "image" + rand.nextInt(999999999) + ".jpg");

    		// Create an image component that gets its contents from the resource.
    		chartArea.addComponent(new Image("Returned Node.js Server Image File:", resource));
    	});
	}
	
	/**
	 * 
	 * @return
	 */
	private Component buildTestTab() {
		VerticalLayout testTabContent = new VerticalLayout();
    	testTabContent.setMargin(true);
    	
    	TextArea textArea = new TextArea("");
    	textArea.setWidth("100%");
    	testTabContent.addComponent(textArea);
    	
    	Button generate = new Button("Generate Chart");
    	testTabContent.addComponent(generate);
    	
    	VerticalLayout chartLayout = new VerticalLayout();
    	chartLayout.setMargin(false);
    	chartLayout.setSpacing(false);
    	testTabContent.addComponent(chartLayout);

    	generate.addClickListener(clickEvent -> {
    		String js = textArea.getValue();
    		HighChartComponent chart = HighChartFactory.renderChart(js);
    		chart.setWidth("100%");
    		chart.setHeight("450px");
    		chartLayout.removeAllComponents();
    		chartLayout.addComponent(chart);
    	});
    	
    	return testTabContent;
    }
	
	/**
	 * 
	 * @return
	 */
	private Panel buildSourceTab() {
		Panel p = new Panel();
		
		p.setWidth("100%");
		p.setHeight("650px");
                
        sourceCode.setContentMode(ContentMode.HTML);
        sourceCode.setSizeUndefined();

        p.setContent(sourceCode);
 
    	return p;
    }
	
	/**
	 * 
	 * @return
	 */
	private Component buildJsTab() {
    	Panel p = new Panel();
		
		p.setWidth("100%");
		p.setHeight("650px");
                
		jsCode.setContentMode(ContentMode.HTML);
		jsCode.setSizeUndefined();

        p.setContent(jsCode);

    	return p;
    }

	/**
	 * 
	 * @param chartFullName
	 */
	private void addSourceCode(String chartFullName) {
		String chartName = chartFullName.substring(chartFullName.lastIndexOf(".") + 1, chartFullName.length());
		StringBuilder codeBuilder = new StringBuilder();
		
	    try (Stream<String> stream = Files.lines(Paths
	    		.get(GeneralUtil.getBasePath() + "/docroot/example/" + chartName + ".java"), StandardCharsets.UTF_8)) {
	    	stream.forEach(line -> {
	    		if (!line.startsWith("//")) {
	    			codeBuilder.append(line).append("\n");
	    		}
	    	});
	    } 
	    catch (IOException e) {
	    	System.err.println("Caught IOException: " + e.getMessage());
	        e.printStackTrace();
	    }

		sourceCode.setValue("<pre class='prettyprint'>" 
                + codeBuilder.toString().replace("&", "&amp;").replace("<", "&lt;").replace(">", "&gt;").replace("\t", "    ") 
                + "</pre>");
	}
	
	/**
	 * 
	 * @param globalOptionsJs
	 * @param chartOptionsJs
	 */
	private void addJs(String globalOptionsJs, String chartOptionsJs) {
		String jsString;
		
		if (globalOptionsJs == null) {
			jsString = chartOptionsJs;
		}
		else {
			jsString = globalOptionsJs + "\n\r" + chartOptionsJs;
		}
		
		jsString = jsString.replace("&", "&amp;").replace("<", "&lt;")
                .replace(">", "&gt;");
		jsCode.setValue("<pre>" + jsString + "</pre>");
	}

}
