package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.AxisType;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.series.SeriesSpline;
import com.hyjavacharts.model.highcharts.series.seriesspline.Data;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;
import com.webonlineapp.hyjavachartsdemo.util.DateUtil;

public class TimeDataWithIrregularIntervals extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();

		chartOptions.getChart().setType(ChartType.SPLINE);
		chartOptions.getTitle().setText("Snow depth at Vikjafjellet, Norway");
		chartOptions.getSubtitle().setText("Irregular time data in Highcharts JS");

		XAxis xAxi = new XAxis();
		xAxi.setType(AxisType.DATETIME)
			.getDateTimeLabelFormats().setMonth("%e. %b").setYear("%b");
		xAxi.getTitle().setText("Date");
		chartOptions.getXAxis().add(xAxi);

		YAxis yAxi = new YAxis();
		yAxi.setMin(0)
			.getTitle().setText("Snow depth (m)");
		chartOptions.getYAxis().add(yAxi);
		
		chartOptions.getTooltip().setHeaderFormat("<b>{series.name}</b><br>").setPointFormat("{point.x:%e. %b}: {point.y:.2f} m");
		chartOptions.getPlotOptions().getSpline().getMarker().setEnabled(true);
		
		chartOptions.setColors(new ArrayList<Color>(Arrays.asList(
				new Color("#6CF"), new Color("#39F"), new Color("#06C"), new Color("#036"), new Color("#000"))));
		
		SeriesSpline seriesSpline = new SeriesSpline();
		seriesSpline.setName("Winter 2014-2015");
		seriesSpline.setDataAsArrayObject(getSeriesData(1));
		chartOptions.getSeries().add(seriesSpline);
		
		seriesSpline = new SeriesSpline();
		seriesSpline.setName("Winter 2015-2016");
		seriesSpline.setDataAsArrayObject(getSeriesData(2));
		chartOptions.getSeries().add(seriesSpline);
		
		seriesSpline = new SeriesSpline();
		seriesSpline.setName("Winter 2016-2017");
		seriesSpline.setDataAsArrayObject(getSeriesData(3));
		chartOptions.getSeries().add(seriesSpline);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	public ArrayList<Data> getSeriesData(int series) {
		ArrayList<Data> array = new ArrayList<Data>();
			
		if (series == 1) {
			array.add(new Data().setX(DateUtil.toMilli(1970, 11, 25)).setY( 0));
            array.add(new Data().setX(DateUtil.toMilli(1970, 12,  6)).setY( 0.25));
            array.add(new Data().setX(DateUtil.toMilli(1970, 12, 20)).setY( 1.41));
            array.add(new Data().setX(DateUtil.toMilli(1970, 12, 25)).setY( 1.64));
            array.add(new Data().setX(DateUtil.toMilli(1971, 1,  4)).setY( 1.6));
            array.add(new Data().setX(DateUtil.toMilli(1971, 1, 17)).setY( 2.55));
            array.add(new Data().setX(DateUtil.toMilli(1971, 1, 24)).setY( 2.62));
            array.add(new Data().setX(DateUtil.toMilli(1971, 2,  4)).setY( 2.5));
            array.add(new Data().setX(DateUtil.toMilli(1971, 2, 14)).setY( 2.42));
            array.add(new Data().setX(DateUtil.toMilli(1971, 3,  6)).setY( 2.74));
            array.add(new Data().setX(DateUtil.toMilli(1971, 3, 14)).setY( 2.62));
            array.add(new Data().setX(DateUtil.toMilli(1971, 3, 24)).setY( 2.6));
            array.add(new Data().setX(DateUtil.toMilli(1971, 4,  1)).setY( 2.81));
            array.add(new Data().setX(DateUtil.toMilli(1971, 4, 11)).setY( 2.63));
            array.add(new Data().setX(DateUtil.toMilli(1971, 4, 27)).setY( 2.77));
            array.add(new Data().setX(DateUtil.toMilli(1971, 5,  4)).setY( 2.68));
            array.add(new Data().setX(DateUtil.toMilli(1971, 5,  9)).setY( 2.56));
            array.add(new Data().setX(DateUtil.toMilli(1971, 5, 14)).setY( 2.39));
            array.add(new Data().setX(DateUtil.toMilli(1971, 5, 19)).setY( 2.3));
            array.add(new Data().setX(DateUtil.toMilli(1971, 6,  4)).setY( 2));
            array.add(new Data().setX(DateUtil.toMilli(1971, 6,  9)).setY( 1.85));
            array.add(new Data().setX(DateUtil.toMilli(1971, 6, 14)).setY( 1.49));
            array.add(new Data().setX(DateUtil.toMilli(1971, 6, 19)).setY( 1.27));
            array.add(new Data().setX(DateUtil.toMilli(1971, 6, 24)).setY( 0.99));
            array.add(new Data().setX(DateUtil.toMilli(1971, 6, 29)).setY( 0.67));
            array.add(new Data().setX(DateUtil.toMilli(1971, 7,  3)).setY( 0.18));
            array.add(new Data().setX(DateUtil.toMilli(1971, 7,  4)).setY( 0));
    	}
    	else if (series == 2) {
    		array.add(new Data().setX(DateUtil.toMilli(1970, 11,  9)).setY( 0));
            array.add(new Data().setX(DateUtil.toMilli(1970, 11, 15)).setY( 0.23));
            array.add(new Data().setX(DateUtil.toMilli(1970, 11, 20)).setY( 0.25));
            array.add(new Data().setX(DateUtil.toMilli(1970, 11, 25)).setY( 0.23));
            array.add(new Data().setX(DateUtil.toMilli(1970, 11, 30)).setY( 0.39));
            array.add(new Data().setX(DateUtil.toMilli(1970, 12,  5)).setY( 0.41));
            array.add(new Data().setX(DateUtil.toMilli(1970, 12, 10)).setY( 0.59));
            array.add(new Data().setX(DateUtil.toMilli(1970, 12, 15)).setY( 0.73));
            array.add(new Data().setX(DateUtil.toMilli(1970, 12, 20)).setY( 0.41));
            array.add(new Data().setX(DateUtil.toMilli(1970, 12, 25)).setY( 1.07));
            array.add(new Data().setX(DateUtil.toMilli(1970, 12, 30)).setY( 0.88));
            array.add(new Data().setX(DateUtil.toMilli(1971, 1,  5)).setY( 0.85));
            array.add(new Data().setX(DateUtil.toMilli(1971, 1, 11)).setY( 0.89));
            array.add(new Data().setX(DateUtil.toMilli(1971, 1, 17)).setY( 1.04));
            array.add(new Data().setX(DateUtil.toMilli(1971, 1, 20)).setY( 1.02));
            array.add(new Data().setX(DateUtil.toMilli(1971, 1, 25)).setY( 1.03));
            array.add(new Data().setX(DateUtil.toMilli(1971, 1, 30)).setY( 1.39));
            array.add(new Data().setX(DateUtil.toMilli(1971, 2,  5)).setY( 1.77));
            array.add(new Data().setX(DateUtil.toMilli(1971, 2, 26)).setY( 2.12));
            array.add(new Data().setX(DateUtil.toMilli(1971, 4, 19)).setY( 2.1));
            array.add(new Data().setX(DateUtil.toMilli(1971, 5,  9)).setY( 1.7));
            array.add(new Data().setX(DateUtil.toMilli(1971, 5, 29)).setY( 0.85));
            array.add(new Data().setX(DateUtil.toMilli(1971, 6,  7)).setY( 0));
    	}
    	else {
    		array.add(new Data().setX(DateUtil.toMilli(1970, 10, 15)).setY( 0));
            array.add(new Data().setX(DateUtil.toMilli(1970, 10, 31)).setY( 0.09));
            array.add(new Data().setX(DateUtil.toMilli(1970, 11,  7)).setY( 0.17));
            array.add(new Data().setX(DateUtil.toMilli(1970, 11, 10)).setY( 0.1));
            array.add(new Data().setX(DateUtil.toMilli(1970, 12, 10)).setY( 0.1));
            array.add(new Data().setX(DateUtil.toMilli(1970, 12, 13)).setY( 0.1));
            array.add(new Data().setX(DateUtil.toMilli(1970, 12, 16)).setY( 0.11));
            array.add(new Data().setX(DateUtil.toMilli(1970, 12, 19)).setY( 0.11));
            array.add(new Data().setX(DateUtil.toMilli(1970, 12, 22)).setY( 0.08));
            array.add(new Data().setX(DateUtil.toMilli(1970, 12, 25)).setY( 0.23));
            array.add(new Data().setX(DateUtil.toMilli(1970, 12, 28)).setY( 0.37));
            array.add(new Data().setX(DateUtil.toMilli(1971, 1, 16)).setY( 0.68));
            array.add(new Data().setX(DateUtil.toMilli(1971, 1, 19)).setY( 0.55));
            array.add(new Data().setX(DateUtil.toMilli(1971, 1, 22)).setY( 0.4));
            array.add(new Data().setX(DateUtil.toMilli(1971, 1, 25)).setY( 0.4));
            array.add(new Data().setX(DateUtil.toMilli(1971, 1, 28)).setY( 0.37));
            array.add(new Data().setX(DateUtil.toMilli(1971, 1, 31)).setY( 0.43));
            array.add(new Data().setX(DateUtil.toMilli(1971, 2,  4)).setY( 0.42));
            array.add(new Data().setX(DateUtil.toMilli(1971, 2,  7)).setY( 0.39));
            array.add(new Data().setX(DateUtil.toMilli(1971, 2, 10)).setY( 0.39));
            array.add(new Data().setX(DateUtil.toMilli(1971, 2, 13)).setY( 0.39));
            array.add(new Data().setX(DateUtil.toMilli(1971, 2, 16)).setY( 0.39));
            array.add(new Data().setX(DateUtil.toMilli(1971, 2, 19)).setY( 0.35));
            array.add(new Data().setX(DateUtil.toMilli(1971, 2, 22)).setY( 0.45));
            array.add(new Data().setX(DateUtil.toMilli(1971, 2, 25)).setY( 0.62));
            array.add(new Data().setX(DateUtil.toMilli(1971, 2, 28)).setY( 0.68));
            array.add(new Data().setX(DateUtil.toMilli(1971, 3,  4)).setY( 0.68));
            array.add(new Data().setX(DateUtil.toMilli(1971, 3,  7)).setY( 0.65));
            array.add(new Data().setX(DateUtil.toMilli(1971, 3, 10)).setY( 0.65));
            array.add(new Data().setX(DateUtil.toMilli(1971, 3, 13)).setY( 0.75));
            array.add(new Data().setX(DateUtil.toMilli(1971, 3, 16)).setY( 0.86));
            array.add(new Data().setX(DateUtil.toMilli(1971, 3, 19)).setY( 1.14));
            array.add(new Data().setX(DateUtil.toMilli(1971, 3, 22)).setY( 1.2));
            array.add(new Data().setX(DateUtil.toMilli(1971, 3, 25)).setY( 1.27));
            array.add(new Data().setX(DateUtil.toMilli(1971, 3, 27)).setY( 1.12));
            array.add(new Data().setX(DateUtil.toMilli(1971, 3, 30)).setY( 0.98));
            array.add(new Data().setX(DateUtil.toMilli(1971, 4,  3)).setY( 0.85));
            array.add(new Data().setX(DateUtil.toMilli(1971, 4,  6)).setY( 1.04));
            array.add(new Data().setX(DateUtil.toMilli(1971, 4,  9)).setY( 0.92));
            array.add(new Data().setX(DateUtil.toMilli(1971, 4, 12)).setY( 0.96));
            array.add(new Data().setX(DateUtil.toMilli(1971, 4, 15)).setY( 0.94));
            array.add(new Data().setX(DateUtil.toMilli(1971, 4, 18)).setY( 0.99));
            array.add(new Data().setX(DateUtil.toMilli(1971, 4, 21)).setY( 0.96));
            array.add(new Data().setX(DateUtil.toMilli(1971, 4, 24)).setY( 1.15));
            array.add(new Data().setX(DateUtil.toMilli(1971, 4, 27)).setY( 1.18));
            array.add(new Data().setX(DateUtil.toMilli(1971, 4, 30)).setY( 1.12));
            array.add(new Data().setX(DateUtil.toMilli(1971, 5,  3)).setY( 1.06));
            array.add(new Data().setX(DateUtil.toMilli(1971, 5,  6)).setY( 0.96));
            array.add(new Data().setX(DateUtil.toMilli(1971, 5,  9)).setY( 0.87));
            array.add(new Data().setX(DateUtil.toMilli(1971, 5, 12)).setY( 0.88));
            array.add(new Data().setX(DateUtil.toMilli(1971, 5, 15)).setY( 0.79));
            array.add(new Data().setX(DateUtil.toMilli(1971, 5, 18)).setY( 0.54));
            array.add(new Data().setX(DateUtil.toMilli(1971, 5, 21)).setY( 0.34));
            array.add(new Data().setX(DateUtil.toMilli(1971, 5, 25)).setY( 0));
    	}
		
    	return array;
    }
}
