package com.webonlineapp.hyjavachartsdemo.examplecharts;

import java.util.ArrayList;
import java.util.Arrays;

import com.hyjavacharts.chart.Highchart;
import com.hyjavacharts.model.common.Color;
import com.hyjavacharts.model.highcharts.ChartOptions;
import com.hyjavacharts.model.highcharts.XAxis;
import com.hyjavacharts.model.highcharts.YAxis;
import com.hyjavacharts.model.highcharts.constants.ChartType;
import com.hyjavacharts.model.highcharts.constants.Stacking;
import com.hyjavacharts.model.highcharts.constants.TickmarkPlacement;
import com.hyjavacharts.model.highcharts.series.SeriesArea;
import com.webonlineapp.hyjavachartsdemo.charts.DemoChartBase;

public class StackedArea extends DemoChartBase {
	
	public Highchart configure() {
		Highchart highChart = new Highchart();
		ChartOptions chartOptions = highChart.getChartOptions();
		
		chartOptions.getChart().setType(ChartType.AREA);
		chartOptions.getTitle().setText("Historic and Estimated Worldwide Population Growth by Region");
		
		chartOptions.getSubtitle().setText("Source: Wikipedia.org");
		
		XAxis xAxi = new XAxis();
		xAxi.setCategories(new ArrayList<String>(Arrays.asList("1750", "1800", "1850", "1900", "1950", "1999", "2050")))
			.setTickmarkPlacement(TickmarkPlacement.ON)
			.getTitle().setText(null);
		chartOptions.getXAxis().add(xAxi);

		YAxis yAxi = new YAxis();
		yAxi.getTitle().setText("Billions");
		yAxi.getLabels().getFormatter().setFunctionBody("return this.value / 1000;");
		chartOptions.getYAxis().add(yAxi);

		chartOptions.getTooltip().split(true).setValueSuffix("millions");

		chartOptions.getPlotOptions().getArea()
			.setStacking(Stacking.NORMAL)
			.setLineColor(new Color("#666666"))
			.setLineWidth(1)
			.getMarker()
				.setLineWidth(1)
				.setLineColor(new Color("#666666"));
		
		SeriesArea seriesArea = new SeriesArea();
		seriesArea.setName("Asia");
		seriesArea.setDataAsArrayNumber(getSeriesData(1));
		chartOptions.getSeries().add(seriesArea);
		
		seriesArea = new SeriesArea();
		seriesArea.setName("Africa");
		seriesArea.setDataAsArrayNumber(getSeriesData(2));
		chartOptions.getSeries().add(seriesArea);
		
		seriesArea = new SeriesArea();
		seriesArea.setName("Europe");
		seriesArea.setDataAsArrayNumber(getSeriesData(3));
		chartOptions.getSeries().add(seriesArea);
		
		seriesArea = new SeriesArea();
		seriesArea.setName("America");
		seriesArea.setDataAsArrayNumber(getSeriesData(4));
		chartOptions.getSeries().add(seriesArea);
		
		seriesArea = new SeriesArea();
		seriesArea.setName("Oceania");
		seriesArea.setDataAsArrayNumber(getSeriesData(5));
		chartOptions.getSeries().add(seriesArea);
		
		return highChart;
	}
	
	/**
	 * 
	 * @param series
	 * @return
	 */
	private ArrayList<Number> getSeriesData(int series) {
    	if (series == 1) {
    		return new ArrayList<Number>(Arrays.asList(502, 635, 809, 947, 1402, 3634, 5268));
    	}
    	else if (series == 2) {
    		return new ArrayList<Number>(Arrays.asList(106, 107, 111, 133, 221, 767, 1766));
    	}
    	else if (series == 3) {
    		return new ArrayList<Number>(Arrays.asList(163, 203, 276, 408, 547, 729, 628));
    	}
    	else if (series == 4) {
    		return new ArrayList<Number>(Arrays.asList(18, 31, 54, 156, 339, 818, 1201));
    	}
    	else {
    		return new ArrayList<Number>(Arrays.asList(2, 2, 2, 6, 13, 30, 46));
    	}
    }
}
